"""restartsh - """

__version__ = '0.1.0'
__author__ = 'fx-kirin <fx.kirin@gmail.com>'
__all__ = []

import logging
import threading
import time

import delegator

logger = logging.getLogger('restartsh')


def restart_thread(cmd, flag, interval=0):
    while not flag.is_set():
        logger.info('Start [CMD]:%s', cmd)
        result = delegator.run(cmd)
        logger.info('Finished [CMD]:%s', cmd)
        if result.ok:
            logger.info('[OUT]%s', result.out)
        else:
            logger.error('[ERR]%s', result.err)
        if (interval > 0):
            logger.info('Sleep %d sec [CMD]', interval)
            time.sleep(interval)
    logger.info("Close by exit_flag")


def restarter(cmd, interval=0):
    flag = threading.Event()
    thread = threading.Thread(target=restart_thread, args=(cmd, flag, interval))
    thread.daemon = True
    thread.start()
    thread.exit_flag = flag

    return thread



import re

from setuptools import find_packages, setup

try:
    from pathlib import Path
except:
    from pathlib2 import Path


def read(filename):
    file_path = Path(__file__).parent / filename
    text_type = type(u"")
    with open(file_path, mode="r", encoding='utf-8') as f:
        return re.sub(text_type(r':[a-z]+:`~?(.*?)`'), text_type(r'``\1``'), f.read())


def get_requires():
    r_path = Path(__file__).parent / 'requirements.txt'
    if r_path.exists():
        with open(r_path) as f:
            required = f.read().splitlines()
    else:
        requred = []
    return required


setup(
    name="restartsh",
    version="0.1.1",
    url="https://github.com/fx-kirin/restartsh",
    license='MIT',

    author="fx-kirin",
    author_email="fx.kirin@gmail.com",

    description="",
    long_description=read("README.rst"),

    packages=find_packages(exclude=('tests',)),

    install_requires=get_requires(),

    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    data_files=[('', ['requirements.txt'])],
)
